@@ -127,6 +127,8 @@ class ExpressionEdit : public QPlainTextEdit {
 		void onCompleterEvent(QEvent*);
 		bool eventFilter(QObject*, QEvent*) override;
 		void setMenuAndToolbarItems(QMenu*, QMenu*, QAction*);
+		bool completionInitialized();
+		void insertText(const QString&);
 
 		std::vector<CalculatorMessage> status_messages;
 
