@@ -20,6 +20,7 @@
 #include <QToolTip>
 #include <QComboBox>
 #include <QLabel>
+#include <QScrollArea>
 #include <QFontDialog>
 #include <QStyleFactory>
 #include <QMessageBox>
@@ -45,23 +46,36 @@ QString font_string(std::string str) {
 	return QString::fromStdString(str);
 }
 
+class PreferencesPageScroll : public QScrollArea {
+	protected:
+		QWidget *child_widget;
+		bool use_child_hint;
+	public:
+		PreferencesPageScroll(QWidget *parent, QWidget *child, bool b) : QScrollArea(parent), child_widget(child), use_child_hint(b) {
+			setWidget(child);
+		}
+		QSize sizeHint() const {
+			if(use_child_hint) {
+				QSize s = child_widget->sizeHint();
+				s.setHeight(s.height() + 1);
+				return s;
+			}
+			return QScrollArea::sizeHint();
+		}
+};
+
 PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	setWindowTitle(tr("Preferences"));
 	QVBoxLayout *topbox = new QVBoxLayout(this);
 	QTabWidget *tabs = new QTabWidget(this);
-	tabs->setUsesScrollButtons(false);
 	topbox->addWidget(tabs);
 	QWidget *w1 = new QWidget(this);
 	QWidget *w2 = new QWidget(this);
 	QWidget *w3 = new QWidget(this);
 	QWidget *w4 = new QWidget(this);
-	tabs->addTab(w1, tr("Look && Feel"));
-	tabs->addTab(w2, tr("Numbers && Operators"));
-	tabs->addTab(w3, tr("Units && Currencies"));
-	tabs->addTab(w4, tr("Parsing && Calculation"));
 	QAbstractButton *box; QGridLayout *l; QComboBox *combo;
 	int r = 0;
-	l = new QGridLayout(w1); l->setSizeConstraint(QLayout::SetFixedSize);
+	l = new QGridLayout(w1);
 	BOX(tr("Ignore system language (requires restart)"), settings->ignore_locale, ignoreLocaleToggled(bool));
 	ignoreLocaleBox = box;
 	QLabel *label = new QLabel(tr("Language:"), this);
@@ -75,6 +89,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->addItem("Français");
 	combo->addItem("ქართული ენა");
 	combo->addItem("Nederlands");
+	combo->addItem("Português");
 	combo->addItem("Português do Brasil");
 	combo->addItem("Русский");
 	combo->addItem("Slovenščina");
@@ -88,19 +103,16 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	else if(lang == "fr") combo->setCurrentIndex(5);
 	else if(lang == "ka") combo->setCurrentIndex(6);
 	else if(lang == "nl") combo->setCurrentIndex(7);
-	else if(lang == "pt") combo->setCurrentIndex(8);
-	else if(lang == "ru") combo->setCurrentIndex(9);
-	else if(lang == "sl") combo->setCurrentIndex(10);
-	else if(lang == "sv") combo->setCurrentIndex(11);
-	else if(lang == "zh") combo->setCurrentIndex(12);
+	else if(settings->custom_lang == "pt_PT") combo->setCurrentIndex(8);
+	else if(lang == "pt") combo->setCurrentIndex(9);
+	else if(lang == "ru") combo->setCurrentIndex(10);
+	else if(lang == "sl") combo->setCurrentIndex(11);
+	else if(lang == "sv") combo->setCurrentIndex(12);
+	else if(lang == "zh") combo->setCurrentIndex(13);
 	else combo->setCurrentIndex(0);
 	combo->setEnabled(!settings->ignore_locale);
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(langChanged(int)));
 	l->addWidget(combo, r, 1); r++; langCombo = combo;
-#ifndef _WIN32
-	label->hide();
-	combo->hide();
-#endif
 	BOX(tr("Allow multiple instances"), settings->allow_multiple_instances > 0, multipleInstancesToggled(bool));
 	BOX(tr("Clear history on exit"), settings->clear_history_on_exit, clearHistoryToggled(bool));
 	l->addWidget(new QLabel(tr("Max history lines saved:"), this), r, 0); QSpinBox *spin = new QSpinBox(this); spin->setRange(0, 100000); spin->setValue(settings->max_history_lines); connect(spin, SIGNAL(valueChanged(int)), this, SLOT(maxHistoryLinesChanged(int))); l->addWidget(spin, r, 1); r++;
@@ -140,7 +152,12 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	QStringList list = QStyleFactory::keys();
 	combo->addItem(tr("Default (requires restart)", "Default style"));
 	combo->addItems(list);
-	combo->setCurrentIndex(settings->style < 0 ? 0 : settings->style + 1);
+	if(settings->style.isEmpty()) {
+		combo->setCurrentIndex(0);
+	} else {
+		int i = list.indexOf(settings->style);
+		combo->setCurrentIndex(i < 0 ? 0 : i + 1);
+	}
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(styleChanged(int)));
 	l->addWidget(combo, r, 1); r++; styleCombo = combo;
 #if defined _WIN32 && (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
@@ -164,7 +181,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	connect(button, SIGNAL(clicked()), this, SLOT(appFontClicked())); connect(box, SIGNAL(toggled(bool)), button, SLOT(setEnabled(bool)));
 	l->setRowStretch(r, 1);
 	r = 0;
-	l = new QGridLayout(w4); l->setSizeConstraint(QLayout::SetFixedSize);
+	l = new QGridLayout(w4);
 	l->addWidget(new QLabel(tr("Expression status:"), this), r, 0);
 	combo = new QComboBox(this);
 	combo->addItem(tr("Off"), 0);
@@ -240,7 +257,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	intervalCalculationCombo = combo;
 	BOX(tr("Factorize result"), settings->evalops.structuring == STRUCTURING_FACTORIZE, factorizeToggled(bool));
 	l->setRowStretch(r, 1);
-	l = new QGridLayout(w2); l->setSizeConstraint(QLayout::SetFixedSize);
+	l = new QGridLayout(w2);
 	r = 0;
 	QGridLayout *l2 = new QGridLayout();
 	l2->addWidget(new QLabel(tr("Two's complement output:"), this), 0, 0);
@@ -330,7 +347,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	complexFormCombo = combo;
 	l->addWidget(combo, r, 1); r++;
 	l->setRowStretch(r, 1);
-	l = new QGridLayout(w3); l->setSizeConstraint(QLayout::SetFixedSize);
+	l = new QGridLayout(w3);
 	r = 0;
 	BOX(tr("Enable units"), settings->evalops.parse_options.units_enabled, unitsToggled(bool));
 	BOX(tr("Abbreviate names"), settings->printops.abbreviate_names, abbreviateNamesToggled(bool));
@@ -389,6 +406,18 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	topbox->addWidget(buttonBox);
 	connect(buttonBox->button(QDialogButtonBox::Close), SIGNAL(clicked()), this, SLOT(reject()));
 	if(settings->always_on_top) setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
+	QSize size = get_screen_geometry(this).size();
+	QSize sh = w1->sizeHint().expandedTo(w2->sizeHint().expandedTo(w3->sizeHint().expandedTo(w4->sizeHint())));
+	if(size.width() >= sh.width() + 100) tabs->setUsesScrollButtons(false);
+	bool use_child_hint = size.height() >= sh.height() + 100;
+	QScrollArea *s1 = new PreferencesPageScroll(this, w1, use_child_hint);
+	QScrollArea *s2 = new PreferencesPageScroll(this, w2, use_child_hint);
+	QScrollArea *s3 = new PreferencesPageScroll(this, w3, use_child_hint);
+	QScrollArea *s4 = new PreferencesPageScroll(this, w4, use_child_hint);
+	tabs->addTab(s1, tr("Look && Feel"));
+	tabs->addTab(s2, tr("Numbers && Operators"));
+	tabs->addTab(s3, tr("Units && Currencies"));
+	tabs->addTab(s4, tr("Parsing && Calculation"));
 }
 PreferencesDialog::~PreferencesDialog() {}
 
@@ -411,11 +440,12 @@ void PreferencesDialog::langChanged(int i) {
 		case 5: {settings->custom_lang = "fr_FR"; break;}
 		case 6: {settings->custom_lang = "ka_GE"; break;}
 		case 7: {settings->custom_lang = "nl_NL"; break;}
-		case 8: {settings->custom_lang = "pt_BR"; break;}
-		case 9: {settings->custom_lang = "ru_RU"; break;}
-		case 10: {settings->custom_lang = "sl_SL"; break;}
-		case 11: {settings->custom_lang = "sv_SE"; break;}
-		case 12: {settings->custom_lang = "zh_CN"; break;}
+		case 8: {settings->custom_lang = "pt_PT"; break;}
+		case 9: {settings->custom_lang = "pt_BR"; break;}
+		case 10: {settings->custom_lang = "ru"; break;}
+		case 11: {settings->custom_lang = "sl_SL"; break;}
+		case 12: {settings->custom_lang = "sv_SE"; break;}
+		case 13: {settings->custom_lang = "zh_CN"; break;}
 	}
 	if(!settings->custom_lang.isEmpty()) {
 		ignoreLocaleBox->setChecked(false);
@@ -824,7 +854,7 @@ void PreferencesDialog::darkModeToggled(bool b) {
 #endif
 }
 void PreferencesDialog::styleChanged(int i) {
-	settings->style = i - 1;
+	settings->style = (i == 0 ? "" : styleCombo->currentText());
 	settings->updateStyle();
 }
 void PreferencesDialog::factorizeToggled(bool b) {
